@@ -1,11 +1,8 @@
-from anvolt.api import Sfw, Nsfw
-from anvolt.trivia import Trivia
-from anvolt.updater import Updater
-from anvolt.utils import Utils
+from anvolt.api import Sfw, Nsfw, Games
 from typing import Optional
 
 __name__ = "anvolt.py"
-__version__ = "0.1.2"
+__version__ = "0.1.3"
 __author__ = "Stawa"
 __license__ = "MIT"
 
@@ -18,3 +15,4 @@ class AnVoltClient:
     ):
         self.sfw = Sfw(client_id=client_id, client_secret=client_secret)
         self.nsfw = Nsfw(client_id=client_id, client_secret=client_secret)
+        self.games = Games(client_id=client_id, client_secret=client_secret)
